@@ -4,8 +4,8 @@
 Pytube: a very serious Python library for downloading YouTube Videos.
 """
 __title__ = "pytube"
-__author__ = "Nick Ficano"
-__license__ = "Unlicensed"
+__author__ = "Ronnie Ghose, Taylor Fox Dahlin, Nick Ficano"
+__license__ = "The Unlicense (Unlicense)"
 __js__ = None
 __js_url__ = None
 
